SWDEV-333188 - Port image tests to catch2 (#2793)

- Port image tests to catch2.
- Disable 3D filter test for gfx9a.
- Some other improvement
- Temporarily disable linear filter tests on Windows

Change-Id: Ieeddac9f8c50aa9b6b12ca9d8fd792a51973b8ca

[ROCm/hip commit: f3c171c984]
Cette révision appartient à :
ROCm CI Service Account
2022-07-19 19:26:56 +05:30
révisé par GitHub
Parent 551f9b4f76
révision 4e58d884c3
24 fichiers modifiés avec 876 ajouts et 124 suppressions
+4 -1
Voir le fichier
@@ -24,14 +24,17 @@ THE SOFTWARE.
texture<float, 1, hipReadModeElementType> tex;
static __global__ void kernel(float *out) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
if (x < N) {
out[x] = tex1Dfetch(tex, x);
}
#endif
}
TEST_CASE("Unit_hipBindTexture_tex1DfetchVerification") {
CHECK_IMAGE_SUPPORT
float *texBuf;
float val[N], output[N];
size_t offset = 0;